@@ -43,7 +43,7 @@ echo "[+] Found $($PYTHON_CMD --version)"
 echo "[*] Checking pipx installation..."
 if ! command_exists pipx; then
     echo "[+] Installing pipx and dependencies..."
-    
+
     # Install pipx based on OS
     if command_exists apt-get; then
         echo ">>> Using apt-get (Debian/Ubuntu)..."
@@ -66,14 +66,14 @@ if ! command_exists pipx; then
         echo ">>> Installing via pip..."
         $PYTHON_CMD -m pip install --user pipx
     fi
-    
+
     # Verify pipx installation
     if ! command_exists pipx && ! $PYTHON_CMD -m pipx --version >/dev/null 2>&1; then
         echo "[!] Failed to install pipx."
         echo ">>> Please install manually: sudo apt install pipx"
         exit 1
     fi
-    
+
     echo "[+] pipx installed successfully."
 else
     echo "[+] pipx is already installed."
@@ -89,16 +89,109 @@ fi
 
 # 4. Install Penguin Tamer via pipx
 echo "[+] Installing Penguin Tamer from PyPI..."
+echo "    This may take a minute - downloading and installing dependencies..."
+echo ""
+
+# Function to show penguin animation
+penguin_spin() {
+    local pid=$1
+    local delay=0.15
+    local width=40
+    local frames=('🐧' '🐧' '🐧' '🐧')
+    local messages=(
+        "Waddling to PyPI..."
+        "Catching packages..."
+        "Installing deps..."
+        "Almost there..."
+    )
+    local pos=0
+    local direction=1
+    local frame=0
+    local msg_idx=0
+    local counter=0
+
+    # Hide cursor
+    tput civis 2>/dev/null || printf "\033[?25l"
+
+    while ps -p $pid > /dev/null 2>&1; do
+        # Clear line
+        printf "\r%*s\r" $((width + 40)) ""
+
+        # Build animation line
+        local line=""
+        local i
+        for ((i=0; i<width; i++)); do
+            if [ $i -eq $pos ]; then
+                line="${line}${frames[$frame]}"
+            else
+                line="${line} "
+            fi
+        done
+
+        # Print with message
+        printf " %s  %s" "$line" "${messages[$msg_idx]}"
+
+        # Update position
+        pos=$((pos + direction))
+
+        # Bounce at edges
+        if [ $pos -ge $((width - 1)) ]; then
+            direction=-1
+        elif [ $pos -le 0 ]; then
+            direction=1
+            msg_idx=$(( (msg_idx + 1) % ${#messages[@]} ))
+        fi
+
+        # Update frame and counter
+        frame=$(( (frame + 1) % ${#frames[@]} ))
+        counter=$((counter + 1))
+
+        sleep $delay
+    done
+
+    # Clear animation line and show cursor
+    printf "\r%*s\r" $((width + 40)) ""
+    tput cnorm 2>/dev/null || printf "\033[?25h"
+}
+
 INSTALL_OUTPUT=""
 if command_exists pipx; then
-    INSTALL_OUTPUT=$(pipx install penguin-tamer --force 2>&1)
+    # Run pipx install in background to show penguin animation
+    pipx install penguin-tamer --force > /tmp/pt_install.log 2>&1 &
+    INSTALL_PID=$!
+    penguin_spin $INSTALL_PID
+    wait $INSTALL_PID
+    INSTALL_EXIT=$?
+    INSTALL_OUTPUT=$(cat /tmp/pt_install.log)
+    rm -f /tmp/pt_install.log
+
+    if [ $INSTALL_EXIT -ne 0 ]; then
+        echo "[!] Installation failed. Output:"
+        echo "$INSTALL_OUTPUT"
+        exit 1
+    fi
 elif $PYTHON_CMD -m pipx --version >/dev/null 2>&1; then
-    INSTALL_OUTPUT=$($PYTHON_CMD -m pipx install penguin-tamer --force 2>&1)
+    $PYTHON_CMD -m pipx install penguin-tamer --force > /tmp/pt_install.log 2>&1 &
+    INSTALL_PID=$!
+    penguin_spin $INSTALL_PID
+    wait $INSTALL_PID
+    INSTALL_EXIT=$?
+    INSTALL_OUTPUT=$(cat /tmp/pt_install.log)
+    rm -f /tmp/pt_install.log
+
+    if [ $INSTALL_EXIT -ne 0 ]; then
+        echo "[!] Installation failed. Output:"
+        echo "$INSTALL_OUTPUT"
+        exit 1
+    fi
 else
     echo "[!] pipx not found after installation. Falling back to pip..."
     $PYTHON_CMD -m pip install --user penguin-tamer --upgrade
 fi
 
+echo "[✓] Download and installation complete!"
+echo ""
+
 # Extract version from pipx output
 INSTALLED_VERSION=""
 if echo "$INSTALL_OUTPUT" | grep -q "installed package penguin-tamer"; then
@@ -124,27 +217,34 @@ done
 # 6. Verify installation
 echo "[*] Verifying installation..."
 if command_exists pt; then
-    echo "[+] Penguin Tamer installed successfully!"
-    
     # Try to get version from pt --version command first
     PT_VERSION=$(pt --version 2>/dev/null | cut -d' ' -f2 2>/dev/null || echo "")
-    
+
     # If that fails, use version from installation output
     if [ -z "$PT_VERSION" ] && [ -n "$INSTALLED_VERSION" ]; then
         PT_VERSION="$INSTALLED_VERSION"
     fi
-    
+
     # Try pipx list as another fallback
     if [ -z "$PT_VERSION" ] && command_exists pipx; then
         PT_VERSION=$(pipx list 2>/dev/null | grep "penguin-tamer" | sed -n 's/.*penguin-tamer \([0-9][^,)]*\).*/\1/p' || echo "")
     fi
-    
+
     # Final fallback
     if [ -z "$PT_VERSION" ]; then
-        PT_VERSION="installed"
+        PT_VERSION="unknown"
     fi
-    
-    echo ">>> Version: $PT_VERSION"
+
+    # Colors (ANSI escape codes)
+    ORANGE='\033[1;38;5;208m'    # Bold Orange (#e07333)
+    TEAL='\033[1;38;5;30m'       # Bold Teal (#007c6e)
+    RESET='\033[0m'              # Reset formatting
+
+    # Print colorful success message with penguin celebration
+    echo ""
+    echo "    🐧  🎉  🐧  🎉  🐧"
+    echo ""
+    echo -e "${ORANGE}Penguin Tamer${RESET} ${TEAL}${PT_VERSION}${RESET} installed successfully!"
     echo ">>> Location: $(which pt)"
 else
     echo "[!] Installation completed, but 'pt' command not found in current PATH."
@@ -178,4 +278,4 @@ echo "[*] Documentation:    https://github.com/Vivatist/penguin-tamer"
 echo "[*] Issues:           https://github.com/Vivatist/penguin-tamer/issues"
 echo ""
 echo "[!] If 'pt' command is not found after restarting terminal:"
-echo "    pipx ensurepath"
\ No newline at end of file
+echo "    pipx ensurepath"
