@@ -38,7 +38,7 @@ import yaml
 import shutil
 import sys
 from pathlib import Path
-from typing import Dict, Any, Optional, List
+from typing import Dict, Any, List
 from platformdirs import user_config_dir
 
 # Добавляем путь к модулю для прямого запуска
@@ -46,6 +46,8 @@ if __name__ == "__main__":
     sys.path.insert(0, str(Path(__file__).parent.parent))
 
 from penguin_tamer.i18n import detect_system_language
+from penguin_tamer.i18n_content import get_default_user_content, is_default_user_content
+from penguin_tamer.utils.descriptors import ConfigProperty
 
 
 class ConfigManager:
@@ -80,22 +82,45 @@ class ConfigManager:
     def _ensure_config_exists(self) -> None:
         """
         Убеждается, что файл конфигурации существует.
-        Если config.yaml не найден, копирует default_config.yaml.
+        Если config.yaml не найден, копирует default_config.yaml с сохранением комментариев.
         """
         if not self.user_config_path.exists():
             if self._default_config_path.exists():
                 try:
+                    # Копируем default_config.yaml в user config
                     shutil.copy2(self._default_config_path, self.user_config_path)
-                    # After creating user config from defaults, set language based on system locale
-                    try:
-                        with open(self.user_config_path, 'r', encoding='utf-8') as f:
-                            cfg = yaml.safe_load(f) or {}
-                        sys_lang = detect_system_language(["en", "ru"]) or "en"
-                        cfg["language"] = sys_lang
-                        with open(self.user_config_path, 'w', encoding='utf-8') as f:
-                            yaml.safe_dump(cfg, f, indent=2, allow_unicode=True, default_flow_style=False, sort_keys=False)
-                    except Exception:
-                        pass
+                    
+                    # Определяем системный язык и локализованный контент
+                    sys_lang = detect_system_language(["en", "ru"]) or "en"
+                    localized_content = get_default_user_content(sys_lang)
+                    
+                    # Читаем скопированный файл как текст для сохранения комментариев
+                    with open(self.user_config_path, 'r', encoding='utf-8') as f:
+                        config_text = f.read()
+                    
+                    # Заменяем язык (первая строка с "language:")
+                    import re
+                    config_text = re.sub(
+                        r'^language:\s*\w+',
+                        f'language: {sys_lang}',
+                        config_text,
+                        count=1,
+                        flags=re.MULTILINE
+                    )
+                    
+                    # Заменяем user_content (многострочное значение)
+                    # Ищем строку "user_content:" и заменяем её значение
+                    config_text = re.sub(
+                        r'(user_content:\s*)[^\n]+',
+                        f'\\1{localized_content}',
+                        config_text,
+                        count=1
+                    )
+                    
+                    # Сохраняем изменённый файл с комментариями
+                    with open(self.user_config_path, 'w', encoding='utf-8') as f:
+                        f.write(config_text)
+                        
                 except Exception as e:
                     raise RuntimeError(f"Не удалось создать файл конфигурации: {e}")
             else:
@@ -198,11 +223,27 @@ class ConfigManager:
         """
         return self._config.copy()
 
-    # === Удобные методы для работы с конкретными настройками ===
+    # === Удобные методы для работы с конкретными настройками (через дескрипторы) ===
+
+    # Основные параметры генерации
+    temperature = ConfigProperty("global", "temperature", 0.7, "Температура генерации ответов")
+    max_tokens = ConfigProperty("global", "max_tokens", None, "Максимум токенов в ответе")
+    top_p = ConfigProperty("global", "top_p", 0.95, "Nucleus sampling (top_p)")
+    frequency_penalty = ConfigProperty("global", "frequency_penalty", 0.0, "Штраф за повторы")
+    presence_penalty = ConfigProperty("global", "presence_penalty", 0.0, "Штраф за упоминание")
+    seed = ConfigProperty("global", "seed", None, "Seed для детерминизма")
+
+    # Top-level параметры
+    language = ConfigProperty("", "language", "en", "UI язык")
+
+    # Дополнительные параметры
+    debug = ConfigProperty("global", "debug", False, "Debug mode enabled/disabled")
+    theme = ConfigProperty("global", "theme", "default", "Current markdown/code theme")
+    user_content = ConfigProperty("global", "user_content", "", "Пользовательский контент для всех LLM")
 
     @property
     def current_llm(self) -> str:
-        """Текущая выбранная LLM."""
+        """Текущая выбранная LLM (custom logic due to naming)."""
         return self.get("global", "current_LLM", "")
 
     @current_llm.setter
@@ -210,76 +251,6 @@ class ConfigManager:
         """Устанавливает текущую LLM."""
         self.set("global", "current_LLM", value)
 
-    @property
-    def user_content(self) -> str:
-        """Пользовательский контент для всех LLM."""
-        return self.get("global", "user_content", "")
-
-    @user_content.setter
-    def user_content(self, value: str) -> None:
-        """Устанавливает пользовательский контент."""
-        self.set("global", "user_content", value)
-
-    @property
-    def temperature(self) -> float:
-        """Температура генерации ответов."""
-        return self.get("global", "temperature", 0.8)
-
-    @temperature.setter
-    def temperature(self, value: float) -> None:
-        """Устанавливает температуру генерации."""
-        self.set("global", "temperature", value)
-
-    @property
-    def max_tokens(self) -> int:
-        """Максимум токенов в ответе."""
-        return self.get("global", "max_tokens", None)
-
-    @max_tokens.setter
-    def max_tokens(self, value: int) -> None:
-        """Устанавливает максимум токенов."""
-        self.set("global", "max_tokens", value)
-
-    @property
-    def top_p(self) -> float:
-        """Nucleus sampling (top_p)."""
-        return self.get("global", "top_p", 0.95)
-
-    @top_p.setter
-    def top_p(self, value: float) -> None:
-        """Устанавливает top_p."""
-        self.set("global", "top_p", value)
-
-    @property
-    def frequency_penalty(self) -> float:
-        """Штраф за повторы."""
-        return self.get("global", "frequency_penalty", 0.0)
-
-    @frequency_penalty.setter
-    def frequency_penalty(self, value: float) -> None:
-        """Устанавливает штраф за повторы."""
-        self.set("global", "frequency_penalty", value)
-
-    @property
-    def presence_penalty(self) -> float:
-        """Штраф за упоминание."""
-        return self.get("global", "presence_penalty", 0.0)
-
-    @presence_penalty.setter
-    def presence_penalty(self, value: float) -> None:
-        """Устанавливает штраф за упоминание."""
-        self.set("global", "presence_penalty", value)
-
-    @property
-    def seed(self) -> int:
-        """Seed для детерминизма."""
-        return self.get("global", "seed", None)
-
-    @seed.setter
-    def seed(self, value: int) -> None:
-        """Устанавливает seed."""
-        self.set("global", "seed", value)
-
     def get_available_llms(self) -> List[str]:
         """
         Возвращает список доступных LLM.
@@ -316,74 +287,126 @@ class ConfigManager:
         """
         return self.get_llm_config(self.current_llm)
 
-    def add_llm(self, name: str, model: str, api_url: str, api_key: str = "") -> None:
+    def get_llm_effective_config(self, llm_name: str) -> Dict[str, Any]:
         """
-        Добавляет новую LLM.
-
+        Возвращает эффективную конфигурацию LLM с данными от провайдера.
+        
         Args:
-            name: Имя LLM
-            model: Модель LLM
-            api_url: API URL
-            api_key: API ключ (опционально)
+            llm_name: Имя LLM
+        
+        Returns:
+            Dict с полями: provider, model, api_url, api_key, client_name
+        """
+        llm_config = self.get_llm_config(llm_name)
+        if not llm_config:
+            return {}
+        
+        provider_name = llm_config.get("provider", "")
+        providers = self.get("supported_Providers") or {}
+        provider_config = providers.get(provider_name, {})
+        
+        return {
+            "provider": provider_name,
+            "model": llm_config.get("model", ""),
+            "api_url": provider_config.get("api_url", ""),
+            "api_key": provider_config.get("api_key", ""),
+            "client_name": provider_config.get("client_name", "openrouter")  # Дефолт для совместимости
+        }
+
+    def get_current_llm_effective_config(self) -> Dict[str, Any]:
+        """
+        Возвращает эффективную конфигурацию текущей LLM.
+        
+        Returns:
+            Dict с полями: provider, model, api_url, api_key
+        """
+        return self.get_llm_effective_config(self.current_llm)
+
+    def _generate_llm_id(self) -> str:
+        """
+        Генерирует уникальный ID для новой LLM.
+        
+        Returns:
+            str: ID в формате "llm_N"
         """
         supported_llms = self.get("supported_LLMs") or {}
+        
+        # Находим максимальный номер среди существующих ID
+        max_num = 0
+        for llm_id in supported_llms.keys():
+            if llm_id.startswith("llm_"):
+                try:
+                    num = int(llm_id.split("_")[1])
+                    max_num = max(max_num, num)
+                except (IndexError, ValueError):
+                    continue
+        
+        # Возвращаем следующий номер
+        return f"llm_{max_num + 1}"
 
-        if name in supported_llms:
-            raise ValueError(f"LLM с именем '{name}' уже существует")
+    def add_llm(self, provider: str, model: str) -> str:
+        """
+        Добавляет новую LLM с автоматически сгенерированным ID.
 
-        supported_llms[name] = {
-            "model": model,
-            "api_url": api_url,
-            "api_key": api_key
+        Args:
+            provider: Провайдер
+            model: Модель LLM
+            
+        Returns:
+            str: Сгенерированный ID новой LLM
+        """
+        supported_llms = self.get("supported_LLMs") or {}
+        
+        # Генерируем уникальный ID
+        llm_id = self._generate_llm_id()
+
+        supported_llms[llm_id] = {
+            "provider": provider,
+            "model": model
         }
 
         self.update_section("supported_LLMs", supported_llms)
+        return llm_id
 
-    def update_llm(self, name: str, model: str = None, api_url: str = None, api_key: str = None) -> None:
+    def update_llm(self, llm_id: str, provider: str = None, model: str = None) -> None:
         """
         Обновляет конфигурацию LLM.
 
         Args:
-            name: Имя LLM для обновления
+            llm_id: ID LLM для обновления
+            provider: Новый провайдер (опционально)
             model: Новая модель (опционально)
-            api_url: Новый API URL (опционально)
-            api_key: Новый API ключ (опционально)
         """
         supported_llms = self.get("supported_LLMs") or {}
 
-        if name not in supported_llms:
-            raise ValueError(f"LLM с именем '{name}' не найдена")
+        if llm_id not in supported_llms:
+            raise ValueError(f"LLM с ID '{llm_id}' не найдена")
 
         # Создаем копию текущей конфигурации
-        current_config = supported_llms[name].copy()
+        current_config = supported_llms[llm_id].copy()
 
+        if provider is not None:
+            current_config["provider"] = provider
         if model is not None:
             current_config["model"] = model
-        if api_url is not None:
-            current_config["api_url"] = api_url
-        if api_key is not None:
-            current_config["api_key"] = api_key
 
         # Обновляем всю секцию supported_LLMs
-        supported_llms[name] = current_config
+        supported_llms[llm_id] = current_config
         self.update_section("supported_LLMs", supported_llms)
 
-    def remove_llm(self, name: str) -> None:
+    def remove_llm(self, llm_id: str) -> None:
         """
         Удаляет LLM.
 
         Args:
-            name: Имя LLM для удаления
+            llm_id: ID LLM для удаления
         """
-        if name == self.current_llm:
-            raise ValueError("Нельзя удалить текущую LLM")
-
         supported_llms = self.get("supported_LLMs") or {}
 
-        if name not in supported_llms:
-            raise ValueError(f"LLM с именем '{name}' не найдена")
+        if llm_id not in supported_llms:
+            raise ValueError(f"LLM с ID '{llm_id}' не найдена")
 
-        del supported_llms[name]
+        del supported_llms[llm_id]
         self.update_section("supported_LLMs", supported_llms)
 
     def reset_to_defaults(self) -> None:
@@ -396,6 +419,28 @@ class ConfigManager:
         else:
             raise FileNotFoundError("Файл с настройками по умолчанию не найден")
 
+    def set_language(self, new_language: str) -> None:
+        """
+        Устанавливает новый язык и автоматически локализует user_content,
+        если он не был изменён пользователем.
+
+        Args:
+            new_language: Новый код языка ('en', 'ru', и т.д.)
+        """
+        current_user_content = self.user_content
+
+        # Проверяем, был ли user_content изменён пользователем
+        # (сравниваем с дефолтным значением любого языка)
+        is_default = is_default_user_content(current_user_content)
+
+        # Обновляем язык
+        self.language = new_language
+
+        # Если user_content не был изменён пользователем, локализуем его
+        if is_default:
+            new_user_content = get_default_user_content(new_language)
+            self.user_content = new_user_content
+
     @property
     def config_path(self) -> Path:
         """Путь к файлу конфигурации."""
@@ -409,45 +454,6 @@ class ConfigManager:
     def __repr__(self) -> str:
         return f"ConfigManager(app_name='{self.app_name}', config_path='{self.user_config_path}')"
 
-    # === Language ===
-    @property
-    def language(self) -> str:
-        """Current UI language (top-level key)."""
-        try:
-            return self._config.get("language", "en")
-        except Exception:
-            return "en"
-
-    @language.setter
-    def language(self, value: str) -> None:
-        try:
-            self._config["language"] = value
-            self._save_config()
-        except Exception:
-            pass
-
-    # === Debug Mode ===
-    @property
-    def debug(self) -> bool:
-        """Debug mode enabled/disabled."""
-        return self.get("global", "debug", False)
-
-    @debug.setter
-    def debug(self, value: bool) -> None:
-        """Set debug mode."""
-        self.set("global", "debug", value)
-
-    # === Theme ===
-    @property
-    def theme(self) -> str:
-        """Current markdown/code theme."""
-        return self.get("global", "theme", "default")
-
-    @theme.setter
-    def theme(self, value: str) -> None:
-        """Set theme."""
-        self.set("global", "theme", value)
-
 
 # Глобальный экземпляр для удобства использования
 config = ConfigManager()
@@ -466,7 +472,7 @@ if __name__ == "__main__":
     # Показываем конфигурацию текущей LLM
     current_llm_config = config.get_current_llm_config()
     print(f"Конфигурация текущей LLM: {current_llm_config}")
-    
+
     # Показываем пути
     print(f"\nПуть к конфигурации: {config.config_path}")
 
